@@ -1049,10 +1049,11 @@ static int resync(m2xxh_t* m2xxh)
     }
     status_check(m2xxh, 0 /* nop */, 0 /* nop */);
     if(m2xxh->error == RFID_ERROR_TRY_AGAIN ||
-       m2xxh->error == RFID_ERROR_UNKNOWN_ERROR) {
+       m2xxh->error == RFID_ERROR_UNKNOWN_ERROR ||
+       m2xxh->error == M2XXH_STATUS_COUPLER_RESET_UNKNOWN) {
       if(m2xxh->verbose > 1)
-	fprintf(stderr, "M2XXH timeout\n");
-      /* Timeout, just try again. */
+	fprintf(stderr, "M2XXH timeout or unknown error\n");
+      /* Timeout or unknown error, just try again. */
     } else if(m2xxh->error == RFID_ERROR_NOT_SUPPORTED || m2xxh->error == 0) {
       /* This is the expected answer. */
       if(m2xxh->verbose > 1)
