@@ -160,11 +160,11 @@ static int bcc_check(u_int8_t* buffer, int buffer_size)
  */
 static int write_request(s6350_t* s6350, int command, u_int8_t* buffer, int buffer_size)
 {
-  char* request;
+  u_int8_t* request;
   short request_length = buffer_size + S6350_REQUEST_OVERHEAD;
   int wrote;
 
-  request = (char*)malloc(buffer_size + S6350_REQUEST_OVERHEAD);
+  request = (u_int8_t*)malloc(buffer_size + S6350_REQUEST_OVERHEAD);
   request_length = buffer_size + S6350_REQUEST_OVERHEAD;
   
   request[S6350_HEADER_SOF] = 0x01;
@@ -202,8 +202,8 @@ static int write_request(s6350_t* s6350, int command, u_int8_t* buffer, int buff
  */
 static int read_answer(s6350_t* s6350, u_int8_t** bufferp, int* buffer_sizep)
 {
-  char answer_header[S6350_REQUEST_HEADER_SIZE];
-  char* buffer;
+  u_int8_t answer_header[S6350_REQUEST_HEADER_SIZE];
+  u_int8_t* buffer;
   u_int16_t length;
   int to_read;
   int offset = 0;
@@ -264,7 +264,7 @@ static int read_answer(s6350_t* s6350, u_int8_t** bufferp, int* buffer_sizep)
 
   to_read = length - S6350_REQUEST_HEADER_SIZE;
 
-  buffer = (char*)malloc(length);
+  buffer = (u_int8_t*)malloc(length);
   memcpy(buffer, answer_header, S6350_REQUEST_HEADER_SIZE);
 
   if(rfid_io_read(s6350->io, buffer + S6350_REQUEST_HEADER_SIZE, to_read) != to_read) {
@@ -347,7 +347,7 @@ int s6350_transponder_details(s6350_t* s6350, s6350_transponder_t* transponder)
 
   memset(transponder, '\0', sizeof(s6350_transponder_t));
 
-  if(write_request(s6350, S6350_COMMAND_READ_TRANSPONDER_DETAILS, "", 0) < 0) {
+  if(write_request(s6350, S6350_COMMAND_READ_TRANSPONDER_DETAILS, (u_int8_t*)"", 0) < 0) {
     RFID_ERROR_STACK(s6350->verbose);
     return -1;
   }
@@ -547,7 +547,7 @@ int s6350_reader_version(s6350_t* s6350, s6350_reader_version_t* reader_version)
   
   clear_error(s6350);
 
-  if(write_request(s6350, S6350_COMMAND_READER_VERSION, "", 0) < 0) {
+  if(write_request(s6350, S6350_COMMAND_READER_VERSION, (u_int8_t*)"", 0) < 0) {
     RFID_ERROR_STACK(s6350->verbose);
     return -1;
   }
@@ -578,7 +578,7 @@ int s6350_reader_version(s6350_t* s6350, s6350_reader_version_t* reader_version)
 
 int s6350_rf_carrier(s6350_t* s6350, u_int8_t on_off)
 {
-  char request[1];
+  u_int8_t request[1];
   u_int8_t* buffer = 0;
   int buffer_size = 0;
 
@@ -614,7 +614,7 @@ int s6350_rf_carrier(s6350_t* s6350, u_int8_t on_off)
 
 int s6350_baud_rate_configuration(s6350_t* s6350, u_int8_t bauds)
 {
-  char request[1];
+  u_int8_t request[1];
   u_int8_t* buffer = 0;
   int buffer_size = 0;
 
@@ -904,7 +904,7 @@ static int drv_init(struct rfid_reader* reader, const char* drivers)
 static void drv_end(struct rfid_reader* reader)
 {
   s6350_t* s6350 = s6350_from_reader(reader);
-  return s6350_end(s6350);
+  s6350_end(s6350);
 }
 
 static char* drv_strerror(struct rfid_reader* reader)
@@ -934,10 +934,11 @@ static void drv_verbose(struct rfid_reader* reader, int verbosity)
 static int drv_read(struct rfid_reader* reader, int block_start, int number_of_blocks, rfid_transponder_t* transponder)
 {
   s6350_t* s6350 = s6350_from_reader(reader);
-  rfid_block_t blocks[number_of_blocks];
+  rfid_block_t* blocks;
   int block_map = 0;
   u_int8_t* pointer;
   int i;
+  int retval;
 
   transponder->data_length = 0;
 
@@ -958,13 +959,19 @@ static int drv_read(struct rfid_reader* reader, int block_start, int number_of_b
 
   pointer = transponder->data + block_start * transponder->bytes_per_block;
   
+  blocks = (rfid_block_t*)malloc(sizeof(rfid_block_t) * number_of_blocks);
+
   for(i = 0; i < number_of_blocks; i++) {
     block_map |= 1 << (block_start + i);
     blocks[i].data = pointer;
     pointer += transponder->bytes_per_block;
   }
   
-  return s6350_special_read_block(s6350, (s6350_transponder_t*)transponder->private, block_map, blocks);
+  retval = s6350_special_read_block(s6350, (s6350_transponder_t*)transponder->private, block_map, blocks);
+
+  free(blocks);
+
+  return retval;
 }
 
 static int drv_write(struct rfid_reader* reader, int block_start, int number_of_blocks, rfid_transponder_t* transponder)
