@@ -86,10 +86,7 @@ int main(int argc, char** argv)
     rfid_io_init(&io, device);
   }
 
-  if(signal(SIGALRM, alarm_f) < 0) {
-    perror("signal(SIGALRM)");
-    return -1;
-  }
+  signal(SIGALRM, alarm_f);
 
   alarm(timeout);
   if(reader->probe_f(reader, "s6350") < 0) {
